LayoutInfo class

A main class of information of Layoutry. Includes the default BoxConstraints (of the LayoutBuilder), and LayoutDevice.

Constructors

LayoutInfo({required BoxConstraints constraints, required LayoutDevice device})
const

Properties

constraints → BoxConstraints
final
device → LayoutDevice
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildFromConstraints(BoxConstraints c) → LayoutInfo
Generates LayoutInfo from the BoxConstraints of the LayoutBuilder. Uses deviceByWeigth to catch the right LayoutDevice by maxWidth.
deviceFromWeight(double w) → LayoutDevice
Generates a LayoutDevice by maxWidth of BoxConstraints.